@@ -6,7 +6,7 @@ use v5.10;
 use base qw( WebService::LiveJournal::Client );
 
 # ABSTRACT: Interface to the LiveJournal API
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 sub _set_error
 {
@@ -27,7 +27,7 @@ WebService::LiveJournal - Interface to the LiveJournal API
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -371,6 +371,12 @@ Returns your friend groups.  This comes as an instance of
 L<WebService::LiveJournal::FriendGroupList> that contains
 zero or more instances of L<WebService::LiveJournal::FriendGroup>.
 
+=head2 $client-E<gt>get_user_tags( [ $journal_name ] )
+
+Fetch the tags associated with the given journal, or the users journal
+if not specified.  This method returns a list of zero or more
+L<WebService::LiveJournal::Tag> objects.
+
 =head2 $client-E<gt>console_command( $command, @arguments )
 
 Execute the given console command with the given arguments on the
